package Bundle::Locale::CLDR::Centralasia;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Centralasia

=head1 CONTENTS

Locale::CLDR::Locales::Kk 0.46.0

Locale::CLDR::Locales::Ky 0.46.0

Locale::CLDR::Locales::Ru 0.46.0

Locale::CLDR::Locales::Tg 0.46.0

Locale::CLDR::Locales::Tk 0.46.0

Locale::CLDR::Locales::Uz 0.46.0

Locale::CLDR::Locales::Kaa 0.46.0

Locale::CLDR::Locales::Kk::Cyrl 0.46.0

Locale::CLDR::Locales::Ky::Cyrl 0.46.0

Locale::CLDR::Locales::Ru::Cyrl 0.46.0

Locale::CLDR::Locales::Tg::Cyrl 0.46.0

Locale::CLDR::Locales::Tk::Latn 0.46.0

Locale::CLDR::Locales::Uz::Cyrl 0.46.0

Locale::CLDR::Locales::Uz::Latn 0.46.0

Locale::CLDR::Locales::Kaa::Cyrl 0.46.0

Locale::CLDR::Locales::Kaa::Latn 0.46.0

Locale::CLDR::Locales::Kk::Cyrl::Kz 0.46.0

Locale::CLDR::Locales::Ky::Cyrl::Kg 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Kg 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Kz 0.46.0

Locale::CLDR::Locales::Tg::Cyrl::Tj 0.46.0

Locale::CLDR::Locales::Tk::Latn::Tm 0.46.0

Locale::CLDR::Locales::Uz::Cyrl::Uz 0.46.0

Locale::CLDR::Locales::Uz::Latn::Uz 0.46.0

Locale::CLDR::Locales::Kaa::Cyrl::Uz 0.46.0

Locale::CLDR::Locales::Kaa::Latn::Uz 0.46.0


=cut

1;

